import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./teaching-bubble.component";
import * as i2 from "@angular/common";
/**
 * @description
 * TeachingBubbleProxyModule provides an Angular wrapper for the Fabric TeachingBubble web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-teaching-bubble [target]="'target-element-id'" [open]="isOpen">
 *   Content of the teaching bubble
 * </fabric-teaching-bubble>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-teaching-bubble
 *   [target]="'target-element-id'"
 *   [placement]="'top'"
 *   [open]="isOpen"
 *   [size]="'medium'"
 *   [disableTrapFocus]="false"
 *   (openchange)="handleOpenChange($event)"
 *   (dismiss)="handleDismiss($event)">
 *
 *   Teaching bubble content
 * </fabric-teaching-bubble>
 * ```
 *
 * ## With Slots
 * ```html
 * <fabric-teaching-bubble [target]="'target-element-id'" [open]="isOpen">
 *   <!-- Image in the teaching bubble -->
 *   <div slot="image">
 *     <img src="example.jpg" alt="Example illustration" />
 *   </div>
 *
 *   <!-- Heading for the teaching bubble -->
 *   <h3 slot="heading">Feature Introduction</h3>
 *
 *   <!-- Main content -->
 *   <p>This feature helps you accomplish your tasks more efficiently.</p>
 *
 *   <!-- Custom close button -->
 *   <button slot="close" aria-label="Close">✕</button>
 *
 *   <!-- Footer with action buttons -->
 *   <div slot="footer">
 *     <fabric-button (click)="onSkip()">Skip</fabric-button>
 *     <fabric-button (click)="onNext()" [appearance]="'primary'">Next</fabric-button>
 *   </div>
 * </fabric-teaching-bubble>
 * ```
 *
 * ## Available Inputs
 * - `target: string` - ID of the target element that the teaching bubble is attached to
 * - `placement: TeachingBubblePlacement` - Placement relative to target: 'top' | 'bottom' | 'left' | 'right' (default: 'top')
 * - `open: boolean` - Whether the teaching bubble is open (default: false)
 * - `disableTrapFocus: boolean` - Whether focus trapping is disabled (default: false)
 * - `size: TeachingBubbleSize` - Size of the teaching bubble: 'small' | 'medium' | 'large' (default: 'medium')
 *
 * ## Available Events
 * - `openchange` - Emitted when the open state changes
 *   - Example: `<fabric-teaching-bubble (openchange)="onOpenChange($event)"></fabric-teaching-bubble>`
 * - `dismiss` - Emitted when the teaching bubble is dismissed
 *   - Example: `<fabric-teaching-bubble (dismiss)="onDismiss($event)"></fabric-teaching-bubble>`
 *
 * ## Available Outputs
 * - `openchange: EventEmitter<any>` - Emitted when the open state changes
 * - `dismiss: EventEmitter<any>` - Emitted when the teaching bubble is dismissed
 *
 * ## Available Slots
 * - `image` - For adding an image to the teaching bubble
 * - `close` - For adding a custom close button
 * - `heading` - For adding a heading to the teaching bubble
 * - `footer` - For adding footer content like action buttons
 * - Default slot - Main content of the teaching bubble
 *
 * @example
 * // In your module:
 * import { TeachingBubbleProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * @NgModule({
 *   imports: [TeachingBubbleProxyModule, ButtonProxyModule]
 * })
 * export class YourModule { }
 *
 * // In your component:
 * @Component({
 *   selector: 'app-feature-tour',
 *   template: `
 *     <div id="target-feature">
 *       <button (click)="showHelp()">Help</button>
 *     </div>
 *
 *     <fabric-teaching-bubble
 *       [target]="'target-feature'"
 *       [open]="showBubble"
 *       [placement]="'right'"
 *       (dismiss)="onDismiss()">
 *       <h3 slot="heading">Feature Help</h3>
 *       <p>This feature lets you manage your account settings.</p>
 *       <div slot="footer">
 *         <fabric-button (click)="onDismiss()">Got it</fabric-button>
 *       </div>
 *     </fabric-teaching-bubble>
 *   `
 * })
 * export class FeatureTourComponent {
 *   showBubble = false;
 *
 *   showHelp() {
 *     this.showBubble = true;
 *   }
 *
 *   onDismiss() {
 *     this.showBubble = false;
 *   }
 * }
 */
export declare class TeachingBubbleProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TeachingBubbleProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<TeachingBubbleProxyModule, [typeof i1.TeachingBubbleComponent], [typeof i2.CommonModule], [typeof i1.TeachingBubbleComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<TeachingBubbleProxyModule>;
}
//# sourceMappingURL=teaching-bubble.module.d.ts.map