import { ApplicationRef, DoBootstrap } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "./wizard.component";
import * as i2 from "@angular/common";
/**
 * @description
 * WizardProxyModule provides an Angular wrapper for the Fabric Wizard web component.
 *
 * ## Basic Usage
 * ```html
 * <fabric-wizard>
 *   <fabric-wizard-step slot="step">Step 1</fabric-wizard-step>
 *   <fabric-wizard-step slot="step">Step 2</fabric-wizard-step>
 *   <fabric-wizard-step slot="step">Step 3</fabric-wizard-step>
 *
 *   <fabric-wizard-panel slot="panel">
 *     <h3>Step 1 Content</h3>
 *     <p>This is the content for step 1.</p>
 *   </fabric-wizard-panel>
 *
 *   <fabric-wizard-panel slot="panel">
 *     <h3>Step 2 Content</h3>
 *     <p>This is the content for step 2.</p>
 *   </fabric-wizard-panel>
 *
 *   <fabric-wizard-panel slot="panel">
 *     <h3>Step 3 Content</h3>
 *     <p>This is the content for step 3.</p>
 *   </fabric-wizard-panel>
 * </fabric-wizard>
 * ```
 *
 * ## With Attributes
 * ```html
 * <fabric-wizard
 *   [ordered]="true"
 *   [disableOnComplete]="true"
 *   [currentIndex]="currentStepIndex"
 *   [ariaLabelledby]="'wizard-title'"
 *   [ariaDescribedby]="'wizard-description'"
 *   (wizardchange)="onWizardChange($event)"
 *   (wizardcomplete)="onWizardComplete($event)">
 *   <!-- Wizard steps and panels -->
 * </fabric-wizard>
 * ```
 *
 * ## Available Inputs
 * - `ordered: boolean` - Whether to show step numbers (default: false)
 * - `disableOnComplete: boolean` - Whether to disable steps after completion (default: false)
 * - `currentIndex: number` - The index of the currently active step (default: 0)
 * - `ariaLabelledby: string` - ID of an element that labels the wizard for accessibility
 * - `ariaDescribedby: string` - ID of an element that describes the wizard for accessibility
 *
 * ## Available Events
 * - `wizardchange` - Emitted when the active step changes
 *   - Example: `<fabric-wizard (wizardchange)="onStepChange($event)"></fabric-wizard>`
 * - `wizardcomplete` - Emitted when all steps are completed
 *   - Example: `<fabric-wizard (wizardcomplete)="onComplete($event)"></fabric-wizard>`
 *
 * ## Available Outputs
 * - `wizardchange: EventEmitter<any>` - Emitted when the active step changes
 * - `wizardcomplete: EventEmitter<any>` - Emitted when all steps are completed
 *
 * ## Available Slots
 * - `step` - For wizard step components
 * - `panel` - For wizard panel components
 *
 * @example
 * ```js
 * // In your module:
 * import { WizardProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { WizardStepProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { WizardPanelProxyModule } from '@fabric-msft/fabric-wrappers';
 * import { ButtonProxyModule } from '@fabric-msft/fabric-wrappers';
 *
 * \@NgModule({
 *   imports: [
 *     WizardProxyModule,
 *     WizardStepProxyModule,
 *     WizardPanelProxyModule,
 *     ButtonProxyModule
 *   ]
 * })
 * export class YourModule { }
 * ```
 *
 * // In your component:
 * ```js
 * \@Component({
 *   selector: 'app-wizard-example',
 *   template: `
 *     <div id="wizard-title" class="sr-only">Configuration Wizard</div>
 *     <div id="wizard-description" class="sr-only">Complete all steps to configure your application</div>
 *
 *     <fabric-wizard
 *       [ordered]="true"
 *       [currentIndex]="currentStep"
 *       [ariaLabelledby]="'wizard-title'"
 *       [ariaDescribedby]="'wizard-description'"
 *       (wizardchange)="onStepChange($event)"
 *       (wizardcomplete)="onWizardComplete($event)">
 *
 *       <fabric-wizard-step slot="step">Account</fabric-wizard-step>
 *       <fabric-wizard-step slot="step">Preferences</fabric-wizard-step>
 *       <fabric-wizard-step slot="step">Review</fabric-wizard-step>
 *
 *       <fabric-wizard-panel slot="panel">
 *         <h3>Account Setup</h3>
 *         <!-- Account form fields -->
 *         <div class="buttons">
 *           <fabric-button (click)="nextStep()">Next</fabric-button>
 *         </div>
 *       </fabric-wizard-panel>
 *
 *       <fabric-wizard-panel slot="panel">
 *         <h3>Preferences</h3>
 *         <!-- Preference options -->
 *         <div class="buttons">
 *           <fabric-button (click)="prevStep()">Back</fabric-button>
 *           <fabric-button (click)="nextStep()" [appearance]="'primary'">Next</fabric-button>
 *         </div>
 *       </fabric-wizard-panel>
 *
 *       <fabric-wizard-panel slot="panel">
 *         <h3>Review</h3>
 *         <!-- Summary and review -->
 *         <div class="buttons">
 *           <fabric-button (click)="prevStep()">Back</fabric-button>
 *           <fabric-button (click)="complete()" [appearance]="'primary'">Complete</fabric-button>
 *         </div>
 *       </fabric-wizard-panel>
 *     </fabric-wizard>
 *   `
 * })
 * export class WizardExampleComponent {
 *   currentStep = 0;
 *
 *   nextStep() {
 *     this.currentStep++;
 *   }
 *
 *   prevStep() {
 *     this.currentStep--;
 *   }
 *
 *   onStepChange(event: any) {
 *     console.log('Step changed:', event);
 *   }
 *
 *   onWizardComplete(event: any) {
 *     console.log('Wizard completed!');
 *   }
 *
 *   complete() {
 *     // Handle completion actions
 *     alert('Wizard completed successfully!');
 *   }
 * }
 * ```
 */
export declare class WizardProxyModule implements DoBootstrap {
    constructor();
    ngDoBootstrap(appRef: ApplicationRef): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<WizardProxyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<WizardProxyModule, [typeof i1.WizardComponent], [typeof i2.CommonModule], [typeof i1.WizardComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<WizardProxyModule>;
}
//# sourceMappingURL=wizard.module.d.ts.map